package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.PosCollect;

/**
 * collectService接口
 * 
 * @author ruoyi
 * @date 2023-06-21
 */
public interface IPosCollectService extends IService<PosCollect>
{
    /**
     * 查询collect
     * 
     * @param id collect主键
     * @return collect
     */
    public PosCollect selectPosCollectById(Long id);

    /**
     * 查询collect列表
     * 
     * @param posCollect collect
     * @return collect集合
     */
    public List<PosCollect> selectPosCollectList(PosCollect posCollect);

    /**
     * 新增collect
     * 
     * @param posCollect collect
     * @return 结果
     */
    public int insertPosCollect(PosCollect posCollect);

    /**
     * 修改collect
     * 
     * @param posCollect collect
     * @return 结果
     */
    public int updatePosCollect(PosCollect posCollect);

    /**
     * 批量删除collect
     * 
     * @param ids 需要删除的collect主键集合
     * @return 结果
     */
    public int deletePosCollectByIds(Long[] ids);

    /**
     * 删除collect信息
     * 
     * @param id collect主键
     * @return 结果
     */
    public int deletePosCollectById(Long id);
}
